# ienv

**!!WARNING!! THIS IS A ONE WAY PROCESS !!WARNING!!**

Have you got 30GB of SciPy on your disk because every time someone wants to
add two numbers together they install a whole lab on your machine? Are your
fifty copies of PyTorch and TensorFlow weighing heavy on your SSD?

Why not throw caution to the wind and replace everyhing in the site-packages
dir with symlinks? It's not like you're going to need them anyway. And nobody
will ever write to them and mess up every venv on your machine. Right?

**!!WARNING!! THIS RECKLESS AND STUPID !!WARNING!!**

## Usage

```shell
pip install ienv
ienv .venv
```

## Recovery

**Pull requests welcome!**

All the files are there, I've just not written anything to bring them back yet.
Ever, probably.

## Credits

Mostly written by ChatGPT just to see if it could do it. With a bit of guidance
it actually could, but it can't learn like that so it's like a student that
nods along and you think it's listening and it's really just playing along and
tricking you into doing its homework. But to be honest it was either that or
copilot anyway.

## License

They say you get what you pay for, sometimes less. This is one of those times.
As free software distributed under the WTFPL (with one additional clause); this
is one of the times when you pay for what you get.
